@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -52,7 +52,7 @@ types: dict[str, str] = {
     "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
     "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
     "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
-    "AWS::ApiGatewayV2::Integration": "dde532823abe537b",
+    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
     "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
     "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
     "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
@@ -88,7 +88,7 @@ types: dict[str, str] = {
     "AWS::AppRunner::VpcIngressConnection": "19e2b06a118c08f3",
     "AWS::AppStream::AppBlock": "60a3a9b8f43b3525",
     "AWS::AppStream::AppBlockBuilder": "3087e48685697649",
-    "AWS::AppStream::Application": "4cf7a3e8ef43ac54",
+    "AWS::AppStream::Application": "357f39e2d6b0b31d",
     "AWS::AppStream::ApplicationEntitlementAssociation": "35e176c811a25063",
     "AWS::AppStream::ApplicationFleetAssociation": "93b71c4884fff935",
     "AWS::AppStream::DirectoryConfig": "d5a3c7fb900c1e1b",
@@ -122,7 +122,7 @@ types: dict[str, str] = {
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "15b478b9836a0d48",
     "AWS::AuditManager::Assessment": "e446f275db12e7a4",
-    "AWS::AutoScaling::AutoScalingGroup": "8fe2b009cdacf409",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -148,8 +148,8 @@ types: dict[str, str] = {
     "AWS::Bedrock::Agent": "bde4b07f1c4b6973",
     "AWS::Bedrock::AgentAlias": "957e2ce5a7007785",
     "AWS::Bedrock::ApplicationInferenceProfile": "4cfe04077b4d87f2",
-    "AWS::Bedrock::Blueprint": "39f4dd55bdb6a9e0",
-    "AWS::Bedrock::DataAutomationProject": "2b48cf97921afb58",
+    "AWS::Bedrock::Blueprint": "9fd78e1aee91ab99",
+    "AWS::Bedrock::DataAutomationProject": "c0ca2febb3ff3851",
     "AWS::Bedrock::DataSource": "9ca916388ec8b805",
     "AWS::Bedrock::Flow": "7d800d89c886b72c",
     "AWS::Bedrock::FlowAlias": "36fa0dff459bcfd0",
@@ -159,8 +159,8 @@ types: dict[str, str] = {
     "AWS::Bedrock::KnowledgeBase": "42afb318cede00fc",
     "AWS::Bedrock::Prompt": "63cb5b7f989bfc36",
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
-    "AWS::BedrockAgentCore::Gateway": "247c1db4e4082ec0",
-    "AWS::BedrockAgentCore::GatewayTarget": "02ee3ce87cb57fbd",
+    "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
+    "AWS::BedrockAgentCore::GatewayTarget": "f190da008ea2a70a",
     "AWS::BedrockAgentCore::WorkloadIdentity": "78d4c036021cc12e",
     "AWS::Budgets::Budget": "ebac0f729cbbf76a",
     "AWS::Budgets::BudgetsAction": "e06dd2791075c9d6",
@@ -168,6 +168,11 @@ types: dict[str, str] = {
     "AWS::CE::AnomalyMonitor": "3238fa7e318e3af7",
     "AWS::CE::AnomalySubscription": "5c01c255f3f4980b",
     "AWS::CE::CostCategory": "0ca417b146507094",
+    "AWS::Cases::CaseRule": "3c901a066e2031a8",
+    "AWS::Cases::Domain": "819687c312320180",
+    "AWS::Cases::Field": "575dad6f219c55da",
+    "AWS::Cases::Layout": "f48d9c43985a0937",
+    "AWS::Cases::Template": "af733164010ae401",
     "AWS::Cassandra::Keyspace": "0bd2067860b304f2",
     "AWS::Cassandra::Table": "cb4f8b935e3eae9c",
     "AWS::Cassandra::Type": "8aec046f867c1dce",
@@ -210,11 +215,11 @@ types: dict[str, str] = {
     "AWS::CloudFront::ConnectionFunction": "d78bd117dcdb2119",
     "AWS::CloudFront::ConnectionGroup": "68ca2c6e67355a40",
     "AWS::CloudFront::ContinuousDeploymentPolicy": "bf0fd1f8e692b34d",
-    "AWS::CloudFront::Distribution": "23e0328c26fb5ba6",
+    "AWS::CloudFront::Distribution": "fab747f0e73ef952",
     "AWS::CloudFront::DistributionTenant": "0645b8023b061e15",
     "AWS::CloudFront::Function": "f3bfd8485e232a78",
     "AWS::CloudFront::KeyGroup": "7a9f609d809f1f8e",
-    "AWS::CloudFront::KeyValueStore": "674d07fa20c06be2",
+    "AWS::CloudFront::KeyValueStore": "59c36f41cb955ac8",
     "AWS::CloudFront::MonitoringSubscription": "f9dae15a96e422a7",
     "AWS::CloudFront::OriginAccessControl": "17f386694e5709fe",
     "AWS::CloudFront::OriginRequestPolicy": "97711158d1bc4353",
@@ -247,8 +252,8 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
     "AWS::CodeGuruProfiler::ProfilingGroup": "c114d737dd6c902d",
-    "AWS::CodeGuruReviewer::RepositoryAssociation": "8c5b9afd83d4c5e2",
-    "AWS::CodePipeline::CustomActionType": "ab3f9c5bbc8251df",
+    "AWS::CodeGuruReviewer::RepositoryAssociation": "74dd544b4ab46609",
+    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
     "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::CodeStar::GitHubRepository": "eaeb2974516b47e3",
@@ -261,6 +266,7 @@ types: dict[str, str] = {
     "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
+    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
     "AWS::Cognito::UserPool": "4294848dd5d358d2",
     "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
@@ -293,7 +299,7 @@ types: dict[str, str] = {
     "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
     "AWS::Connect::EmailAddress": "807b7160b3385afb",
     "AWS::Connect::EvaluationForm": "f723bee2405abd32",
-    "AWS::Connect::HoursOfOperation": "a135dc27c162fc0e",
+    "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
     "AWS::Connect::Instance": "818f2e8da01f29d9",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
     "AWS::Connect::IntegrationAssociation": "05d606eba9d7fcad",
@@ -320,7 +326,7 @@ types: dict[str, str] = {
     "AWS::ControlTower::EnabledControl": "ac0e492fde8853d9",
     "AWS::ControlTower::LandingZone": "96c88ada196eeb0e",
     "AWS::CustomerProfiles::CalculatedAttributeDefinition": "81da3130233325a0",
-    "AWS::CustomerProfiles::Domain": "659c111393e9e906",
+    "AWS::CustomerProfiles::Domain": "aa830cf9368f9f97",
     "AWS::CustomerProfiles::EventStream": "3f1d9d2ece69a5a6",
     "AWS::CustomerProfiles::EventTrigger": "433ae33b7ce88aca",
     "AWS::CustomerProfiles::Integration": "cc301ddea32cd660",
@@ -332,7 +338,7 @@ types: dict[str, str] = {
     "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
     "AWS::DMS::Certificate": "89efe57b4144e9ab",
     "AWS::DMS::DataMigration": "ade967581e1dfc34",
-    "AWS::DMS::DataProvider": "7c7365975be25275",
+    "AWS::DMS::DataProvider": "94c68c86840900fc",
     "AWS::DMS::Endpoint": "945bb565b81d0034",
     "AWS::DMS::EventSubscription": "fdd5de7c61bc5946",
     "AWS::DMS::InstanceProfile": "b289107706553b44",
@@ -362,13 +368,13 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
     "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
     "AWS::DataSync::Task": "d896b335ffc11f10",
-    "AWS::DataZone::Connection": "4c5bd872b555a360",
-    "AWS::DataZone::DataSource": "45679439037c4108",
+    "AWS::DataZone::Connection": "36206200921236e5",
+    "AWS::DataZone::DataSource": "5522a6a5cd1e1a3e",
     "AWS::DataZone::Domain": "a73fade42476d81b",
     "AWS::DataZone::DomainUnit": "711f0c6aabf717bd",
     "AWS::DataZone::Environment": "90d9cbf3a3ed746b",
     "AWS::DataZone::EnvironmentActions": "74f98b0cb8b35451",
-    "AWS::DataZone::EnvironmentBlueprintConfiguration": "3aeda3b79f4458c1",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration": "2eaef7d5eed54c20",
     "AWS::DataZone::EnvironmentProfile": "e0cb32e5d86cbc08",
     "AWS::DataZone::FormType": "c4cdf1e5e0a284ed",
     "AWS::DataZone::GroupProfile": "74ae2ae09d16d68e",
@@ -376,8 +382,8 @@ types: dict[str, str] = {
     "AWS::DataZone::PolicyGrant": "4a122be9c506c908",
     "AWS::DataZone::Project": "2f7d1fc808f3eed8",
     "AWS::DataZone::ProjectMembership": "9afaeb6b2c0a7ad8",
-    "AWS::DataZone::ProjectProfile": "fb23ccf55c4c1ec7",
-    "AWS::DataZone::SubscriptionTarget": "b9b0c7c5b0d7c587",
+    "AWS::DataZone::ProjectProfile": "069e12fef6b972f5",
+    "AWS::DataZone::SubscriptionTarget": "ed731ffbd196f802",
     "AWS::DataZone::UserProfile": "db3a5863b7d055bd",
     "AWS::Deadline::Farm": "c9bbcca2240de1e6",
     "AWS::Deadline::Fleet": "b90dfd2bd6566e09",
@@ -403,20 +409,21 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
     "AWS::DocDBElastic::Cluster": "5686e00f54e9aae6",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::CarrierGateway": "ac1f397e6adda506",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
-    "AWS::EC2::ClientVpnEndpoint": "9927a4c168876daf",
+    "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -426,7 +433,7 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "ba21ffd03e701456",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
@@ -468,7 +475,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -506,7 +513,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -524,12 +531,12 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECS::CapacityProvider": "e838474b874da177",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
-    "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
+    "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
-    "AWS::ECS::Service": "75313434fba04f66",
+    "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
     "AWS::ECS::TaskSet": "93284b06523a426d",
     "AWS::EFS::AccessPoint": "2f62161de474e688",
@@ -541,13 +548,13 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EMR::Studio": "5562dc4dee066fd3",
     "AWS::EMR::StudioSessionMapping": "68073ac17f83b5d4",
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
@@ -606,13 +613,13 @@ types: dict[str, str] = {
     "AWS::FSx::Volume": "e2217632738abb7f",
     "AWS::GameLift::Alias": "5c014b121a693be2",
     "AWS::GameLift::Build": "b9b218f4180db0c3",
-    "AWS::GameLift::Fleet": "7b1de719fe632688",
+    "AWS::GameLift::Fleet": "08322d2081d018bb",
     "AWS::GameLift::GameServerGroup": "5cc95b605dfa9939",
     "AWS::GameLift::GameSessionQueue": "aba577170457cc78",
     "AWS::GameLift::Location": "74151dc88b4069da",
     "AWS::GameLift::MatchmakingConfiguration": "b3a52351df7bf443",
     "AWS::GameLift::MatchmakingRuleSet": "8e5d97e0ee9acaa8",
-    "AWS::GameLift::Script": "d2777b50e200b1a3",
+    "AWS::GameLift::Script": "4571db51b8dc638d",
     "AWS::GlobalAccelerator::Accelerator": "8c74434fcd81b4e7",
     "AWS::GlobalAccelerator::CrossAccountAttachment": "8c37543e6efb0b27",
     "AWS::GlobalAccelerator::EndpointGroup": "f81aee5bef7cb0c1",
@@ -637,7 +644,7 @@ types: dict[str, str] = {
     "AWS::Glue::SchemaVersionMetadata": "e531f6334f8eeda7",
     "AWS::Glue::SecurityConfiguration": "066142ba850e9899",
     "AWS::Glue::Table": "2528cdc058dacdf8",
-    "AWS::Glue::TableOptimizer": "301880d31f452b08",
+    "AWS::Glue::TableOptimizer": "6b0597c4dd2d5360",
     "AWS::Glue::Trigger": "efdf04c0265f5aff",
     "AWS::Glue::UsageProfile": "c43f6252ac5a4f73",
     "AWS::Glue::Workflow": "7889f86fa2b1958f",
@@ -735,7 +742,7 @@ types: dict[str, str] = {
     "AWS::IoT::ThingGroup": "7fa472878da23f08",
     "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
     "AWS::IoT::ThingType": "472326c990487efa",
-    "AWS::IoT::TopicRule": "b031e429916b85bb",
+    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
     "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
     "AWS::IoTEvents::AlarmModel": "9663bd41a6ba5243",
     "AWS::IoTEvents::DetectorModel": "0527d423b1402c41",
@@ -743,7 +750,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kendra::DataSource": "46ba2f6e9c75d715",
@@ -812,13 +819,13 @@ types: dict[str, str] = {
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
     "AWS::Logs::Integration": "0bc4c86432380358",
     "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
     "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
     "AWS::Logs::SubscriptionFilter": "57635d7dc5bd3e61",
-    "AWS::Logs::Transformer": "4d1796b2fa0445b0",
+    "AWS::Logs::Transformer": "66b4b09c596d83c0",
     "AWS::M2::Application": "7c1b78891b93a215",
     "AWS::M2::Deployment": "a4f5b6e67e1de730",
     "AWS::M2::Environment": "556251194fbbcc67",
@@ -873,7 +880,7 @@ types: dict[str, str] = {
     "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
     "AWS::MediaPackageV2::ChannelGroup": "2aa9c5f3fad67e76",
     "AWS::MediaPackageV2::ChannelPolicy": "e79aba75cf23e354",
-    "AWS::MediaPackageV2::OriginEndpoint": "14921a18e39abb19",
+    "AWS::MediaPackageV2::OriginEndpoint": "ebe0f0a5cdb97975",
     "AWS::MediaPackageV2::OriginEndpointPolicy": "8cd12a52dceffffe",
     "AWS::MediaStore::Container": "3566cc35a249c49c",
     "AWS::MemoryDB::ACL": "92db73d1650765a6",
@@ -963,7 +970,7 @@ types: dict[str, str] = {
     "AWS::PCS::ComputeNodeGroup": "18c1af5cf4154c64",
     "AWS::PCS::Queue": "beffbb3966cc89c2",
     "AWS::PaymentCryptography::Alias": "04360ee15415de2d",
-    "AWS::PaymentCryptography::Key": "af3314970ea9b730",
+    "AWS::PaymentCryptography::Key": "af26a71fe21eb480",
     "AWS::Pinpoint::ADMChannel": "fc1f95e86736d23b",
     "AWS::Pinpoint::APNSChannel": "c0374468e811dfbd",
     "AWS::Pinpoint::APNSSandboxChannel": "6fdd937d9f67edc1",
@@ -990,10 +997,10 @@ types: dict[str, str] = {
     "AWS::QLDB::Ledger": "eb38fe7089c60665",
     "AWS::QLDB::Stream": "09aa8fbe0fae7277",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
-    "AWS::QuickSight::Dashboard": "c75bfb3b0c668dfa",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
+    "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -1002,14 +1009,14 @@ types: dict[str, str] = {
     "AWS::QuickSight::VPCConnection": "96804832324c84da",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
-    "AWS::RDS::CustomDBEngineVersion": "e9699c76b9971105",
+    "AWS::RDS::CustomDBEngineVersion": "67b3a7d6ee10021d",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -1056,7 +1063,7 @@ types: dict[str, str] = {
     "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
     "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
@@ -1074,7 +1081,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "bc2a891a463ee5ee",
+    "AWS::S3::Bucket": "f2e96ae4922bbb57",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3::MultiRegionAccessPoint": "193323be1bf2dac0",
     "AWS::S3::MultiRegionAccessPointPolicy": "7ac84076052ddd16",
@@ -1095,7 +1102,7 @@ types: dict[str, str] = {
     "AWS::S3Vectors::VectorBucket": "eae6d86b8ee33282",
     "AWS::S3Vectors::VectorBucketPolicy": "ecd7e75e3e0d291d",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -1183,7 +1190,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Project": "c10c82bc5a09a5dc",
     "AWS::SageMaker::Space": "a50f6b85f86355b5",
     "AWS::SageMaker::StudioLifecycleConfig": "5b453bb7816eb95b",
-    "AWS::SageMaker::UserProfile": "d2a4b7455b2cbd74",
+    "AWS::SageMaker::UserProfile": "6300c02533605472",
     "AWS::SageMaker::Workteam": "d617e40122a8fe93",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
@@ -1195,7 +1202,7 @@ types: dict[str, str] = {
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::AutomationRuleV2": "382b90fb3949f096",
     "AWS::SecurityHub::ConfigurationPolicy": "acb80ff79b887cb5",
-    "AWS::SecurityHub::ConnectorV2": "11285780497e0a3f",
+    "AWS::SecurityHub::ConnectorV2": "b4e780d54c354d65",
     "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
     "AWS::SecurityHub::FindingAggregator": "7a4c95623ee48fcd",
     "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
@@ -1303,21 +1310,21 @@ types: dict[str, str] = {
     "AWS::WAFv2::RuleGroup": "b1d084941142148b",
     "AWS::WAFv2::WebACL": "892990086386d387",
     "AWS::WAFv2::WebACLAssociation": "d0181fa0b0d2faac",
-    "AWS::Wisdom::AIAgent": "a27424c39bbaeffd",
+    "AWS::Wisdom::AIAgent": "5ee8ab1c7c6da31a",
     "AWS::Wisdom::AIAgentVersion": "ebc006eddb995353",
     "AWS::Wisdom::AIGuardrail": "b55d708e74222e39",
     "AWS::Wisdom::AIGuardrailVersion": "18170fb3d4df70e6",
-    "AWS::Wisdom::AIPrompt": "7d88936dace0860f",
+    "AWS::Wisdom::AIPrompt": "839755a4af72ed27",
     "AWS::Wisdom::AIPromptVersion": "f1eb16962e464a28",
     "AWS::Wisdom::Assistant": "b334f5c54b6c51a1",
-    "AWS::Wisdom::AssistantAssociation": "8208fce50ec6026e",
+    "AWS::Wisdom::AssistantAssociation": "5f451a4494207cd5",
     "AWS::Wisdom::KnowledgeBase": "7a9b74f6c142ebfc",
     "AWS::Wisdom::MessageTemplate": "abd2a7d623bd398f",
     "AWS::Wisdom::MessageTemplateVersion": "85d93c94b16a675a",
     "AWS::Wisdom::QuickResponse": "f1a6189fe08948ad",
     "AWS::WorkSpaces::ConnectionAlias": "da70493ea10990d6",
     "AWS::WorkSpaces::Workspace": "97435699d74bcbe8",
-    "AWS::WorkSpaces::WorkspacesPool": "f4472bf2fa403578",
+    "AWS::WorkSpaces::WorkspacesPool": "321a927105979c95",
     "AWS::WorkSpacesThinClient::Environment": "7bbf7b66606e0a09",
     "AWS::WorkSpacesWeb::BrowserSettings": "c64ccfb879da5c48",
     "AWS::WorkSpacesWeb::DataProtectionSettings": "07a9150a1ae32491",
@@ -1328,7 +1335,7 @@ types: dict[str, str] = {
     "AWS::WorkSpacesWeb::SessionLogger": "cbc5dd3254f28e39",
     "AWS::WorkSpacesWeb::TrustStore": "0da7818c34767162",
     "AWS::WorkSpacesWeb::UserAccessLoggingSettings": "13399f9f750bfb0f",
-    "AWS::WorkSpacesWeb::UserSettings": "c335346f36ab680a",
+    "AWS::WorkSpacesWeb::UserSettings": "ba71e0f7174cdbe2",
     "AWS::WorkspacesInstances::Volume": "783536e2ad8748b1",
     "AWS::WorkspacesInstances::VolumeAssociation": "de659b329d22edbd",
     "AWS::WorkspacesInstances::WorkspaceInstance": "d9e9f739e378d7cd",
